lcvtoolbox.core.schemas.CvatApiJobDetailsDict
=============================================

.. currentmodule:: lcvtoolbox.core.schemas

.. autoclass:: CvatApiJobDetailsDict
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CvatApiJobDetailsDict.__init__
      ~CvatApiJobDetailsDict.clear
      ~CvatApiJobDetailsDict.copy
      ~CvatApiJobDetailsDict.fromkeys
      ~CvatApiJobDetailsDict.get
      ~CvatApiJobDetailsDict.items
      ~CvatApiJobDetailsDict.keys
      ~CvatApiJobDetailsDict.pop
      ~CvatApiJobDetailsDict.popitem
      ~CvatApiJobDetailsDict.setdefault
      ~CvatApiJobDetailsDict.update
      ~CvatApiJobDetailsDict.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CvatApiJobDetailsDict.id
      ~CvatApiJobDetailsDict.task_id
      ~CvatApiJobDetailsDict.project_id
      ~CvatApiJobDetailsDict.assignee
      ~CvatApiJobDetailsDict.guide_id
      ~CvatApiJobDetailsDict.dimension
      ~CvatApiJobDetailsDict.data_compressed_chunk_type
      ~CvatApiJobDetailsDict.data_original_chunk_type
      ~CvatApiJobDetailsDict.bug_tracker
      ~CvatApiJobDetailsDict.mode
      ~CvatApiJobDetailsDict.frame_count
      ~CvatApiJobDetailsDict.start_frame
      ~CvatApiJobDetailsDict.stop_frame
      ~CvatApiJobDetailsDict.data_chunk_size
      ~CvatApiJobDetailsDict.created_date
      ~CvatApiJobDetailsDict.updated_date
      ~CvatApiJobDetailsDict.issues
      ~CvatApiJobDetailsDict.labels
      ~CvatApiJobDetailsDict.type
      ~CvatApiJobDetailsDict.organization
   
   